Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authormegumi.telles2017-03-28 20:18:58 +0000
committerRyan T. Baldwin2017-03-28 20:18:58 +0000
commit52425be27a6ade155c0eddb72b65c5c0f645bbe0 (patch)
tree7ec25f501adc2eaa76433fe1d9da5f3e83d9a29c /plugins/org.eclipse.osee.define/src
parentbd8885970729f73b4cac2dc396d0517e11c1c4ba (diff)
downloadorg.eclipse.osee-52425be27a6ade155c0eddb72b65c5c0f645bbe0.tar.gz
org.eclipse.osee-52425be27a6ade155c0eddb72b65c5c0f645bbe0.tar.xz
org.eclipse.osee-52425be27a6ade155c0eddb72b65c5c0f645bbe0.zip
refinement: Allow other type of publish to use master and slave
Diffstat (limited to 'plugins/org.eclipse.osee.define/src')
-rw-r--r--plugins/org.eclipse.osee.define/src/org/eclipse/osee/define/blam/operation/PublishWithSpecifiedTemplate.java6
1 files changed, 4 insertions, 2 deletions
diff --git a/plugins/org.eclipse.osee.define/src/org/eclipse/osee/define/blam/operation/PublishWithSpecifiedTemplate.java b/plugins/org.eclipse.osee.define/src/org/eclipse/osee/define/blam/operation/PublishWithSpecifiedTemplate.java
index 10738115bd5..eee7a1019f2 100644
--- a/plugins/org.eclipse.osee.define/src/org/eclipse/osee/define/blam/operation/PublishWithSpecifiedTemplate.java
+++ b/plugins/org.eclipse.osee.define/src/org/eclipse/osee/define/blam/operation/PublishWithSpecifiedTemplate.java
@@ -346,8 +346,10 @@ public class PublishWithSpecifiedTemplate extends AbstractBlam {
@Override
public void modifyText(ModifyEvent e) {
- // only enable slave template selection if Master is for SRS.
- if (masterCombo.get().contains("srsMaster")) {
+ // only enable slave template selection if Master is for SRS or Engineering Worksheets (EWS)
+ String masterTemplate = masterCombo.get();
+ if (masterTemplate.contains("srsMaster") || //
+ masterTemplate.contains("ewsMaster")) {
slaveWidget.setEnabled(true);
orcsQueryWidget.setEditable(false);
orcsQueryWidget.set("");

Back to the top